==> nextcloud-14.0.1.tgz: nextcloud/apps/files_sharing/l10n/hu.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Megosztva másokkal",
    "Shared with you" : "Megosztva veled",
    "Shared by link" : "Megosztva hivatkozással",
    "Deleted shares" : "Törölt megosztások",
    "Shares" : "Megosztások",
    "Nothing shared with you yet" : "Nincs még semmi megosztva veled",
    "Files and folders others share with you will show up here" : "Mások által megosztott fájlok és mappák itt jelennek meg",
    "Nothing shared yet" : "Nincs semmi megosztva",
    "Files and folders you share will show up here" : "Az Ön által megosztott fájlok és mappák itt jelennek meg",
    "No shared links" : "Nincs megosztott hivatkozás",
    "Files and folders you share by link will show up here" : "A hivatkozással megosztott fájlok és mappák itt jelennek meg",
    "No deleted shares" : "Nincs törölt megosztás",
    "Shares you deleted will show up here" : "A törölt megosztások itt jelennek meg",
    "No shares" : "Nincs megosztás",
    "Shares will show up here" : "A megosztások itt jelennek meg",
    "Restore share" : "Megosztás visszaállítása",
    "Something happened. Unable to restore the share." : "Hiba történt. Nem lehet visszaállítani a megosztást.",
    "Move or copy" : "Mozgatás vagy másolás",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "You can upload into this folder" : "Ebbe a mappába fel tud tölteni",
    "No compatible server found at {remote}" : "Itt nem található kompatibilis szerver: {remote}",
    "Invalid server URL" : "Érvénytelen szerver URL",
    "Failed to add the public link to your Nextcloud" : "Nem sikerült hozzáadni a nyilvános hivatkozást a Nexcloudodhoz",
    "Share" : "Megosztás",
    "No expiration date set" : "Nem lett beállítva lejárati dátum",
    "Shared by" : "Megosztotta:",
    "Sharing" : "Megosztás",
    "File shares" : "Fájl megosztások",
    "Downloaded via public link" : "Letöltve nyilvános hivatkozással",
    "Downloaded by {email}" : "Letöltötte: {email}",
    "{file} downloaded via public link" : "{file} letöltve nyilvános hibatkozással",
    "{email} downloaded {file}" : "{email} letöltötte ezt: {file}",
    "Shared with group {group}" : "Megosztva ezzel a csoporttal: {group}",
    "Removed share for group {group}" : "{group} csoport megosztása eltávolítva",
    "{actor} shared with group {group}" : "{actor} megosztva ezzel a csoporttal: {group}",
    "{actor} removed share for group {group}" : "{actor} eltávolította {group} csoport megosztását",
    "You shared {file} with group {group}" : "Megosztottad ezt: {file} ezzel a csoporttal: {group}",
    "You removed group {group} from {file}" : "Eltávolítottad ezt csoportot:  {group} innen:  {file}",
    "{actor} shared {file} with group {group}" : "{actor} megosztotta ezt: {file} ezzel a csoporttal: {group}",
    "{actor} removed group {group} from {file}" : "{actor} eltávolította ezt a csoportot {group} innen: {file}",
    "Shared as public link" : "Megosztva nyilvános hivatkozásként",
    "Removed public link" : "Eltávolított nyilvános hivatkozás",
    "Public link expired" : "Nyilvános hivatkozás lejárt",
    "{actor} shared as public link" : "{actor} megosztva nyilvános hivatkozásként",
    "{actor} removed public link" : "{actor} eltávolított egy nyilvános hivatkozást",
    "Public link of {actor} expired" : "{actor} nyilvános hivatkozása lejárt",
    "You shared {file} as public link" : "Nyilvános hivatkozáskánt megosztottad ezt: {file}",
    "You removed public link for {file}" : "Eltávolítottad {file} nyilvános hivatkozását",
    "Public link expired for {file}" : "{file} nyilvános hivatkozása lejárt",
    "{actor} shared {file} as public link" : "{actor}  nyilvános hivatkozásként megosztotta ezt: {file}",
    "{actor} removed public link for {file}" : "{actor} eltávolította {file} nyilvános hivatkozását",
    "Public link of {actor} for {file} expired" : "{actor} nyilvános hivatkozása lejárt ehhez: {file}",
    "{user} accepted the remote share" : "{user} elfogadta a távoli megosztást",
    "{user} declined the remote share" : "{user} visszautasította a távoli megosztást",
    "You received a new remote share {file} from {user}" : "Egy új távoli megosztást kaptál ehhez: {file} tőle: {user}",
    "{user} accepted the remote share of {file}" : "{user} elfogadta {file} távoli megosztását",
    "{user} declined the remote share of {file}" : "{user} visszautasította {file} távoli megosztását",
    "{user} unshared {file} from you" : "{user} visszavonta tőled {file} megosztását",
    "Shared with {user}" : "Megosztva vele: {user}",
    "Removed share for {user}" : "{user} megosztása eltávolítva",
    "{actor} shared with {user}" : "{actor} megosztotta vele: {user}",
    "{actor} removed share for {user}" : "{actor} eltávolította {user} megosztását",
    "Shared by {actor}" : "Megosztotta: {actor}",
    "{actor} removed share" : "{actor} eltávolította a megosztást",
    "You shared {file} with {user}" : "Megosztottad ezt: {file} vele: {user}",
    "You removed {user} from {file}" : "Eltávolítottad ezt: {user} tőle: {file}",
    "{actor} shared {file} with {user}" : "{actor} megosztotta ezt: {file} vele: {user}",
    "{actor} removed {user} from {file}" : "{actor} eltávolította ezt: {user} innen: {file}",
    "{actor} shared {file} with you" : "{actor} megosztotta veled ezt: {file}",
    "{actor} removed you from the share named {file}" : "{actor} eltávolított a {file} nevű megosztásból",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Egy e-mailben vagy nyilvános hivatkozással megosztott fájl vagy mappa <strong>letöltve</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Egy fájl vagy mappa meg lett osztva egy <strong>másik szerverről</strong>",
    "A file or folder has been <strong>shared</strong>" : "Egy fájl vagy mappa <strong>megosztva</strong>",
    "Wrong share ID, share doesn't exist" : "Hibás megosztás ID, a megosztás nem létezik",
    "could not delete share" : "a megosztás nem törölhető",
    "Could not delete share" : "A megosztás nem törölhető",
    "Please specify a file or folder path" : "Adj meg egy fájl vagy mappa útvonalat",
    "Wrong path, file/folder doesn't exist" : "Hibás útvonal, a fájl/mappa nem létezik",
    "Could not create share" : "A megosztás nem hozható létre",
    "invalid permissions" : "érvénytelen jogosultságok",
    "Please specify a valid user" : "Kérlek adj meg egy érvényes felhasználót",
    "Group sharing is disabled by the administrator" : "A csoportos megosztást letiltotta az adminisztrátor",
    "Please specify a valid group" : "Kérlek adj meg egy érvényes csoportot",
    "Public link sharing is disabled by the administrator" : "A nyilvános hivatkozást megosztást letiltotta az adminisztrátor",
    "Public upload disabled by the administrator" : "A nyilvános feltöltést letiltotta az adminisztrátor",
    "Public upload is only possible for publicly shared folders" : "A nyilvános feltöltés csak a nyilvánosan megosztott mappákban lehetséges",
    "Invalid date, date format must be YYYY-MM-DD" : "Érvénytelen dátum, a dátum csak YYYY-MM-DD formátumú lehet",
    "Sharing %s failed because the back end does not allow shares from type %s" : "%s megosztása sikertelen, mert a háttér rendszer nem engedélyezi a következő típusú megosztásokat: %s",
    "You cannot share to a Circle if the app is not enabled" : "Nem tudod megosztani egy Körrel, ha az alkalmazás nem engedélyezett",
    "Please specify a valid circle" : "Kérlek adj meg egy érvényes Kört",
    "Unknown share type" : "Ismeretlen megosztás típus",
    "Not a directory" : "Nem könyvtár",
    "Could not lock path" : "Az útvonal nem zárolható",
    "Wrong or no update parameter given" : "Hibás vagy üres frissítési paraméter",
    "Can't change permissions for public share links" : "Nem lehet módosítani a nyilvános megosztási hivatkozások jogosultságait",
    "Cannot increase permissions" : "Nem lehet növelni az engedélyeket",
    "shared by %s" : "megosztotta %s",
    "Direct link" : "Közvetlen hivatkozás",
    "Add to your Nextcloud" : "Add hozzá a Nextcloudodhoz",
    "Share API is disabled" : "Megosztás API letiltva",
    "File sharing" : "Fájlmegosztás",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Name" : "Név",
    "Share time" : "A megosztás időpontja",
    "Expiration date" : "Lejárati dátum",
    "Sorry, this link doesn’t seem to work anymore." : "Sajnos úgy tűnik, ez a hivatkozás már nem működik.",
    "Reasons might be:" : "Ennek az oka a következő lehet:",
    "the item was removed" : "az elem el lett távolítva",
    "the link expired" : "lejárt a hivatkozás érvényességi ideje",
    "sharing is disabled" : "letiltásra került a megosztás",
    "For more info, please ask the person who sent this link." : "További információért fordulj ahhoz, aki ezt a linket küldte neked!",
    "Share note" : "Jegyzet megosztása",
    "Download %s" : "%s letöltése",
    "Upload files to %s" : "Fájlok felöltése ide: %s",
    "Select or drop files" : "Válassz ki vagy dobj ide fájlokat",
    "Uploading files…" : "Fájlok feltöltése...",
    "Uploaded files:" : "Felöltött fájlok:",
    "{actor} removed you from {file}" : "{actor} eltávolított innen: {file}",
    "%s is publicly shared" : "%s nyilvánosan megosztva",
    "This share is password-protected" : "Ez egy jelszóval védett megosztás",
    "The password is wrong. Try again." : "A megadott jelszó nem megfelelő. Próbálja újra!",
    "Password" : "Jelszó"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/files_sharing/l10n/hu.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Megosztva Önnel",
    "Nothing shared with you yet" : "Még semmi sincs megosztva Önnel",
    "Files and folders others share with you will show up here" : "A mások által megosztott fájlok és mappák itt jelennek meg",
    "Shared with others" : "Megosztva másokkal",
    "Nothing shared yet" : "Még semmi sincs megosztva",
    "Files and folders you share will show up here" : "Az Ön által megosztott fájlok és mappák itt jelennek meg",
    "Shared by link" : "Megosztva hivatkozással",
    "No shared links" : "Nincs megosztott hivatkozás",
    "Files and folders you share by link will show up here" : "A hivatkozással megosztott fájlok és mappák itt jelennek meg",
    "Deleted shares" : "Törölt megosztások",
    "No deleted shares" : "Nincs törölt megosztás",
    "Shares you deleted will show up here" : "A törölt megosztások itt jelennek meg",
    "Shares" : "Megosztások",
    "No shares" : "Nincs megosztás",
    "Shares will show up here" : "A megosztások itt jelennek meg",
    "Restore" : "Visszaállítás",
    "Restore share" : "Megosztás visszaállítása",
    "Something happened. Unable to restore the share." : "Hiba történt. Nem lehet visszaállítani a megosztást.",
    "error" : "hiba",
    "This will stop your current uploads." : "Ez meg fogja állítani a jelenlegi feltöltéseket.",
    "Move or copy" : "Áthelyezés vagy másolás",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "You can upload into this folder" : "Ebbe a mappába fel tud tölteni",
    "Terms of service" : "Szolgáltatási feltételek",
    "No compatible server found at {remote}" : "Nem található kompatibilis kiszolgáló itt: {remote}",
    "Invalid server URL" : "Érvénytelen kiszolgáló URL",
    "Failed to add the public link to your Nextcloud" : "Nem sikerült hozzáadni a nyilvános hivatkozást a Nexcloudjához",
    "No expiration date set" : "Nincs beállítva lejárati dátum",
    "Shared by" : "Megosztotta:",
    "File shares" : "Fájlmegosztások",
    "Downloaded via public link" : "Letöltve nyilvános hivatkozással",
    "Downloaded by {email}" : "Letöltötte: {email}",
    "{file} downloaded via public link" : "{file} nyilvános hivatkozással letöltve",
    "{email} downloaded {file}" : "{email} letöltötte ezt: {file}",
    "Shared with group {group}" : "Megosztva ezzel a csoporttal: {group}",
    "Removed share for group {group}" : "{group} csoport megosztása eltávolítva",
    "{actor} shared with group {group}" : "{actor} megosztotta ezzel a csoporttal: {group}",
    "{actor} removed share for group {group}" : "{actor} eltávolította {group} csoport megosztását",
    "You shared {file} with group {group}" : "Megosztottad ezt: {file} ezzel a csoporttal: {group}",
    "You removed group {group} from {file}" : "Eltávolítottad ezt csoportot:  {group} innen:  {file}",
    "{actor} shared {file} with group {group}" : "{actor} megosztotta ezt: {file} ezzel a csoporttal: {group}",
    "{actor} removed group {group} from {file}" : "{actor} eltávolította ezt a csoportot {group} innen: {file}",
    "Shared as public link" : "Megosztva nyilvános hivatkozásként",
    "Removed public link" : "Eltávolított nyilvános hivatkozás",
    "Public link expired" : "Nyilvános hivatkozás lejárt",
    "{actor} shared as public link" : "{actor} megosztva nyilvános hivatkozásként",
    "{actor} removed public link" : "{actor} eltávolított egy nyilvános hivatkozást",
    "Public link of {actor} expired" : "{actor} nyilvános hivatkozása lejárt",
    "You shared {file} as public link" : "Nyilvános hivatkozáskánt megosztottad ezt: {file}",
    "You removed public link for {file}" : "Eltávolítottad {file} nyilvános hivatkozását",
    "Public link expired for {file}" : "{file} nyilvános hivatkozása lejárt",
    "{actor} shared {file} as public link" : "{actor}  nyilvános hivatkozásként megosztotta ezt: {file}",
    "{actor} removed public link for {file}" : "{actor} eltávolította {file} nyilvános hivatkozását",
    "Public link of {actor} for {file} expired" : "{actor} nyilvános hivatkozása lejárt ehhez: {file}",
    "{user} accepted the remote share" : "{user} elfogadta a távoli megosztást",
    "{user} declined the remote share" : "{user} visszautasította a távoli megosztást",
    "You received a new remote share {file} from {user}" : "Egy új távoli megosztást kaptál ehhez: {file} tőle: {user}",
    "{user} accepted the remote share of {file}" : "{user} elfogadta {file} távoli megosztását",
    "{user} declined the remote share of {file}" : "{user} visszautasította {file} távoli megosztását",
    "{user} unshared {file} from you" : "{user} visszavonta tőled {file} megosztását",
    "Shared with {user}" : "Megosztva vele: {user}",
    "Removed share for {user}" : "{user} megosztása eltávolítva",
    "You removed yourself" : "Eltávolítottad magadat",
    "{actor} removed themselves" : "{actor} eltávolították magukat",
    "{actor} shared with {user}" : "{actor} megosztotta vele: {user}",
    "{actor} removed share for {user}" : "{actor} eltávolította {user} megosztását",
    "Shared by {actor}" : "Megosztotta: {actor}",
    "{actor} removed share" : "{actor} eltávolította a megosztást",
    "You shared {file} with {user}" : "Megosztottad ezt: {file} vele: {user}",
    "You removed {user} from {file}" : "Eltávolítottad ezt: {user} tőle: {file}",
    "You removed yourself from {file}" : "Eltávolítottad magad innen: {file}",
    "{actor} removed themselves from {file}" : "{actor} eltávolították magukat a {file}-ból",
    "{actor} shared {file} with {user}" : "{actor} megosztotta ezt: {file} vele: {user}",
    "{actor} removed {user} from {file}" : "{actor} eltávolította ezt: {user} innen: {file}",
    "{actor} shared {file} with you" : "{actor} megosztotta veled ezt: {file}",
    "{actor} removed you from the share named {file}" : "{actor} eltávolított a {file} nevű megosztásból",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Egy e-mailben vagy nyilvános hivatkozással megosztott fájl vagy mappa <strong>letöltve</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Egy fájl vagy mappa meg lett osztva egy <strong>másik szerverről</strong>",
    "A file or folder has been <strong>shared</strong>" : "Egy fájl vagy mappa <strong>megosztva</strong>",
    "Wrong share ID, share doesn't exist" : "Hibás megosztás ID, a megosztás nem létezik",
    "Could not delete share" : "A megosztás nem törölhető",
    "Please specify a file or folder path" : "Adj meg egy fájl vagy mappa útvonalat",
    "Wrong path, file/folder doesn't exist" : "Hibás útvonal, a fájl/mappa nem létezik",
    "Could not create share" : "A megosztás nem hozható létre",
    "invalid permissions" : "érvénytelen jogosultságok",
    "Please specify a valid user" : "Kérlek adj meg egy érvényes felhasználót",
    "Group sharing is disabled by the administrator" : "A csoportos megosztást letiltotta a rendszergazda",
    "Please specify a valid group" : "Kérlek adj meg egy érvényes csoportot",
    "Public link sharing is disabled by the administrator" : "A nyilvános hivatkozást megosztást letiltotta a rendszergazda",
    "Public upload disabled by the administrator" : "A nyilvános feltöltést letiltotta a rendszergazda",
    "Public upload is only possible for publicly shared folders" : "A nyilvános feltöltés csak a nyilvánosan megosztott mappákban lehetséges",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "A Nextcloud Beszélgetés %s megosztásának küldése nem sikerült mert a Nextcloud Beszélgetés nem engedélyezett",
    "Invalid date, date format must be YYYY-MM-DD" : "Érvénytelen dátum, a dátum csak YYYY-MM-DD formátumú lehet",
    "You cannot share to a Circle if the app is not enabled" : "Nem tudod megosztani egy Körrel, ha az alkalmazás nem engedélyezett",
    "Please specify a valid circle" : "Kérlek adj meg egy érvényes Kört",
    "Unknown share type" : "Ismeretlen megosztás típus",
    "Not a directory" : "Nem könyvtár",
    "Could not lock path" : "Az útvonal nem zárolható",
    "Wrong or no update parameter given" : "Hibás vagy üres frissítési paraméter",
    "Can't change permissions for public share links" : "Nem lehet módosítani a nyilvános megosztási hivatkozások jogosultságait",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "A Nextcloud Beszélgetés jelszó megosztásának küldése nem sikerült mert a Nextcloud Beszélgetés nem engedélyezett",
    "shared by %s" : "megosztotta %s",
    "Download all files" : "Összes fájl letöltése",
    "Direct link" : "Közvetlen hivatkozás",
    "Add to your Nextcloud" : "Add hozzá a Nextcloudodhoz",
    "Share API is disabled" : "Megosztás API letiltva",
    "File sharing" : "Fájlmegosztás",
    "Accept" : "Elfogad",
    "Sharing" : "Megosztás",
    "Allow editing" : "Szerkesztés engedélyezése",
    "Allow resharing" : "A megosztás továbbadásának engedélyezése",
    "Expiration date enforced" : "Lejárati idő kötelező",
    "Set expiration date" : "Lejárati idő beállítása",
    "Note to recipient" : "Jegyzet a címzettnek",
    "Unshare" : "Megosztás visszavonása",
    "group" : "csoport",
    "conversation" : "beszélgetés",
    "remote" : "távoli",
    "remote group" : "távoli csoport",
    "guest" : "vendég",
    "Link copied" : "Hivatkozás másolva",
    "Copy to clipboard" : "Másolás vágólapra",
    "Only works for users with access to this folder" : "Csak azoknál a felhasználóknál működik, akiknek hozzáférése van ehhez a mappához",
    "Password protection" : "Jelszavas védelem",
    "Enter a password" : "Adja meg a jelszót",
    "Cancel" : "Mégse",
    "Read only" : "Csak olvasható",
    "Allow upload and editing" : "Feltöltés és szerkesztés engedélyezése",
    "File drop (upload only)" : "Fájl ejtés (csak feltöltés)",
    "Hide download" : "Letöltés elrejtése",
    "Password protect" : "Jelszóvédelem",
    "Add another link" : "További hivatkozás hozzáadása",
    "Share link" : "Hivatkozás megosztása",
    "Resharing is not allowed" : "Az újra megosztás nem engedélyezett",
    "Searching …" : "Keresés ...",
    "Search globally" : "Keresés globálisan",
    "Shared" : "Megosztva",
    "Share" : "Megosztás",
    "Shared with" : "Megosztva vele:",
    "Shared with you and the group {group} by {owner}" : "{owner} megosztotta Önnel és ezzel a csoporttal: {group}",
    "Shared with you and {circle} by {owner}" : "{owner} megosztotta Önnel és ezzel a csoporttal: {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} megosztotta Önnel és ezzel a beszélgetéssel: {conversation}",
    "Shared with you in a conversation by {owner}" : "{owner} megosztotta Önnel egy beszélgetésben",
    "Shared with you by {owner}" : "Megosztotta Önnel: {owner}",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Name" : "Név",
    "Share time" : "A megosztás időpontja",
    "Expiration date" : "Lejárati dátum",
    "Sorry, this link doesn’t seem to work anymore." : "Sajnos úgy tűnik, ez a hivatkozás már nem működik.",
    "Reasons might be:" : "Ennek az oka a következő lehet:",
    "the item was removed" : "az elem el lett távolítva",
    "the link expired" : "lejárt a hivatkozás érvényességi ideje",
    "sharing is disabled" : "letiltásra került a megosztás",
    "For more info, please ask the person who sent this link." : "További információért fordulj ahhoz, aki ezt a linket küldte neked!",
    "Share note" : "Jegyzet megosztása",
    "Toggle grid view" : "Rácsnézet váltás",
    "Download %s" : "%s letöltése",
    "Upload files to %s" : "Fájlok feltöltése ide: %s",
    "Note" : "Megjegyzés",
    "Select or drop files" : "Válassz ki vagy dobj ide fájlokat",
    "Uploaded files:" : "Feltöltött fájlok:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Fájlok feltöltésével elfogadja a %1$sszolgáltatási feltételek %2$s.",
    "could not delete share" : "a megosztás nem törölhető",
    "Uploading files…" : "Fájlok feltöltése..."
},
"nplurals=2; plural=(n != 1);");
